@@ -1,5 +1,5 @@
 use crate::{
-    models::{Account, Hotspot, Oui, Validator},
+    models::{transactions::Transaction, Account, Hotspot, Oui, QueryTimeRange, Validator},
     *,
 };
 
@@ -34,13 +34,16 @@ pub fn validators(client: &Client, address: &str) -> Stream<Validator> {
 /// descending order
 pub async fn richest(client: &Client, limit: Option<u32>) -> Result<Vec<Account>> {
     client
-        .fetch(
-            &format!("/accounts/rich?limit={}", limit.unwrap_or(1000)),
-            NO_QUERY,
-        )
+        .fetch("/accounts/rich", &[("limit", limit.unwrap_or(1000))])
         .await
 }
 
+/// Fetches transactions that indicate activity for an account. This includes any
+/// transaction that involves the account, usually as a payer, payee or owner.
+pub fn activity(client: &Client, address: &str, query: &QueryTimeRange) -> Stream<Transaction> {
+    client.fetch_stream(&format!("/accounts/{}/activity", address), query)
+}
+
 #[cfg(test)]
 mod test {
     use super::*;
@@ -49,14 +52,12 @@ mod test {
     #[test]
     async fn all() {
         let client = Client::default();
-        let accounts =
-            accounts::all(&client)
-                .take(10)
-                .fold(vec![], |mut acc, account| async move {
-                    acc.push(account.unwrap().address);
-                    acc
-                });
-        assert_eq!(accounts.await.len(), 10);
+        let accounts = accounts::all(&client)
+            .take(10)
+            .into_vec()
+            .await
+            .expect("accounts");
+        assert_eq!(accounts.len(), 10);
     }
 
     #[test]
@@ -105,7 +106,7 @@ mod test {
         let client = Client::default();
         let richest = accounts::richest(&client, Some(10))
             .await
-            .expect("richet list");
+            .expect("richest list");
         assert_eq!(richest.len(), 10);
     }
 }
