@@ -12,10 +12,8 @@ pub type Future<T> = Pin<Box<dyn StdFuture<Output = Result<T>> + Send>>;
 pub type Stream<T> = Pin<Box<dyn StdStream<Item = Result<T>> + Send>>;
 
 mod error;
-mod values;
 
 pub use error::{Error, Result};
-pub use values::{Dbi, Hnt, Hst, Usd};
 
 pub mod accounts;
 pub mod blocks;
@@ -24,6 +22,7 @@ pub mod models;
 pub mod oracle;
 pub mod ouis;
 pub mod pending_transactions;
+pub mod transactions;
 pub mod validators;
 pub mod vars;
 
@@ -47,28 +46,21 @@ pub struct Client {
     client: reqwest::Client,
 }
 
-impl Default for Client {
-    /// Create a new client using the hosted Helium API at
-    /// explorer.helium.foundation
-    fn default() -> Self {
-        Self::new_with_base_url(DEFAULT_BASE_URL.to_string())
-    }
-}
-
 impl Client {
     /// Create a new client using a given base URL and a default
     /// timeout. The library will use absoluate paths based on this
     /// base_url.
-    pub fn new_with_base_url(base_url: String) -> Self {
-        Self::new_with_timeout(base_url, DEFAULT_TIMEOUT)
+    pub fn new_with_base_url(base_url: String, user_agent: &str) -> Self {
+        Self::new_with_timeout(base_url, user_agent, DEFAULT_TIMEOUT)
     }
 
     /// Create a new client using a given base URL, and request
     /// timeout value.  The library will use absoluate paths based on
     /// the given base_url.
-    pub fn new_with_timeout(base_url: String, timeout: u64) -> Self {
+    pub fn new_with_timeout(base_url: String, user_agent: &str, timeout: u64) -> Self {
         let client = reqwest::Client::builder()
             .gzip(true)
+            .user_agent(user_agent)
             .timeout(Duration::from_secs(timeout))
             .build()
             .unwrap();
@@ -114,13 +106,23 @@ impl Client {
                             Some(entry) => Ok(Some((entry, (data, client, path)))),
                             None => match data.cursor {
                                 Some(cursor) => {
-                                    let mut data = client
-                                        .fetch_data::<Vec<E>, _>(&path, &[("cursor", &cursor)])
-                                        .await?;
-                                    data.data.reverse();
-                                    match data.data.pop() {
-                                        Some(entry) => Ok(Some((entry, (data, client, path)))),
-                                        None => Ok(None),
+                                    //loop until we find next bit of data or run
+                                    // out of cursors
+                                    let mut data: Data<Vec<E>>;
+                                    let mut cursor = cursor;
+                                    loop {
+                                        data = client
+                                            .fetch_data::<Vec<E>, _>(&path, &[("cursor", &cursor)])
+                                            .await?;
+
+                                        if !data.data.is_empty() {
+                                            data.data.reverse();
+                                            let entry = data.data.pop().unwrap();
+                                            break Ok(Some((entry, (data, client, path))));
+                                        } else if data.cursor.is_none() {
+                                            break Ok(None);
+                                        }
+                                        cursor = data.cursor.unwrap();
                                     }
                                 }
                                 None => Ok(None),
@@ -168,23 +170,16 @@ impl Client {
     }
 }
 
-#[async_trait]
-pub trait IntoVec {
-    type Item;
-
-    async fn into_vec(self) -> Result<Vec<Self::Item>>;
-}
+impl<T: ?Sized> IntoVec for T where T: StdStream {}
 
 #[async_trait]
-impl<T> IntoVec for Stream<T>
-where
-    T: std::marker::Send,
-{
-    type Item = T;
-    async fn into_vec(self) -> Result<Vec<Self::Item>> {
-        self.collect::<Vec<error::Result<Self::Item>>>()
-            .await
-            .into_iter()
-            .collect()
+pub trait IntoVec: StreamExt {
+    async fn into_vec<T>(self) -> Result<Vec<T>>
+    where
+        Self: Sized,
+        T: std::marker::Send,
+        Vec<Result<T>>: Extend<Self::Item>,
+    {
+        self.collect::<Vec<Result<T>>>().await.into_iter().collect()
     }
 }
